==> anyremote-5.0.tar.gz: anyremote-5.0/src/cmds.h <==
//
// anyRemote
// a bluetooth remote for your PC.
//
// Copyright (C) 2006,2007,2008,2009 Mikhail Fedotov <anyremote@mail.ru>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
//

#ifndef _CMDS_H
#define _CMDS_H

#include "parse.h"

#define PARAM_START     "$("
#define PARAM_CALLID    "CallId)"
#define PARAM_MODE      "Mode)"
#define PARAM_PARAM     "Param)"
#define PARAM_INDEX     "Index)"
#define PARAM_CFGDIR    "CfgDir)"
#define PARAM_HOME      "Home)"
#define PARAM_BTADDR    "BtAddr)"

#define SEND_STRING     "string"
#define SEND_BYTES      "bytes"

void	setToFile	(void);
void 	handleCmdByKey  (type_key* k, cmdParams *p);
void    handleCmdByKeyEx(type_key* k, cmdParams* p, int sendToMain);
int 	processCommands (cmdItem* cmdList, cmdParams *p);
int 	execDynamically (char *command);
void	flushOldConf	(void);
int	handleHook      (int hook);

#endif

==> anyremote-5.3.tar.gz: anyremote-5.3/src/cmds.h <==
//
// anyRemote
// a bluetooth remote for your PC.
//
// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
//

#ifndef _CMDS_H
#define _CMDS_H

#include "parse.h"

#define PARAM_START     "$("
#define PARAM_CALLID    "CallId)"
#define PARAM_MODE      "Mode)"
#define PARAM_PARAM     "Param)"
#define PARAM_INDEX     "Index)"
#define PARAM_CFGDIR    "CfgDir)"
#define PARAM_HOME      "Home)"
#define PARAM_BTADDR    "BtAddr)"

#define SEND_STRING     "string"
#define SEND_BYTES      "bytes"

void	setToFile	(void);
int  	handleCmdByKey  (type_key* k, cmdParams *p);
int     handleCmdByKeyEx(type_key* k, cmdParams* p, int sendToMain);
int 	processCommands (cmdItem* cmdList, cmdParams *p);
int 	execDynamically (char *command);
void	flushOldConf	(void);
int	handleHook      (int hook);

#endif
